==> galette-0.9.6.1.tar.bz2: galette-0.9.6.1/galette/lib/Galette/Entity/PdfAdhesionFormModel.php <==
<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * PDF adhesion form model
 *
 * PHP version 5
 *
 * Copyright © 2013-2021 The Galette Team
 *
 * This file is part of Galette (http://galette.tuxfamily.org).
 *
 * Galette is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Galette is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Galette. If not, see <http://www.gnu.org/licenses/>.
 *
 * @category  Entity
 * @package   Galette
 *
 * @author    Guillaume Rousse <guillomovitch@gmail.com>
 * @copyright 2013-2021 The Galette Team
 * @license   http://www.gnu.org/licenses/gpl-3.0.html GPL License 3.0 or (at your option) any later version
 * @link      http://galette.tuxfamily.org
 * @since     Available since 0.8.3dev - 2014-07-02
 */

namespace Galette\Entity;

/**
 * PDF form model
 *
 * @category  Entity
 * @name      PdfAdhesionFormModel
 * @package   Galette
 * @author    Guillaume Rousse <guillomovitch@gmail.com>
 * @copyright 2013-2021 The Galette Team
 * @license   http://www.gnu.org/licenses/gpl-3.0.html GPL License 3.0 or (at your option) any later version
 * @link      http://galette.tuxfamily.org
 * @since     Available since 0.8.3dev - 2014-07-02
 */

class PdfAdhesionFormModel extends PdfModel
{
    /**
     * Main constructor
     *
     * @param Db          $zdb         Database instance
     * @param Preferences $preferences Galette preferences
     * @param mixed       $args        Arguments
     */
    public function __construct($zdb, $preferences, $args = null)
    {
        parent::__construct($zdb, $preferences, self::ADHESION_FORM_MODEL, $args);
        $this->setPatterns($this->getMemberPatterns());
    }
}

==> galette-1.0.3.tar.bz2: galette-1.0.3/galette/lib/Galette/Entity/PdfAdhesionFormModel.php <==
<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * PDF adhesion form model
 *
 * PHP version 5
 *
 * Copyright © 2013-2023 The Galette Team
 *
 * This file is part of Galette (http://galette.tuxfamily.org).
 *
 * Galette is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Galette is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Galette. If not, see <http://www.gnu.org/licenses/>.
 *
 * @category  Entity
 * @package   Galette
 *
 * @author    Guillaume Rousse <guillomovitch@gmail.com>
 * @copyright 2013-2023 The Galette Team
 * @license   http://www.gnu.org/licenses/gpl-3.0.html GPL License 3.0 or (at your option) any later version
 * @link      http://galette.tuxfamily.org
 * @since     Available since 0.8.3dev - 2014-07-02
 */

namespace Galette\Entity;

use Galette\Core\Db;
use Galette\Core\Preferences;

/**
 * PDF form model
 *
 * @category  Entity
 * @name      PdfAdhesionFormModel
 * @package   Galette
 * @author    Guillaume Rousse <guillomovitch@gmail.com>
 * @copyright 2013-2023 The Galette Team
 * @license   http://www.gnu.org/licenses/gpl-3.0.html GPL License 3.0 or (at your option) any later version
 * @link      http://galette.tuxfamily.org
 * @since     Available since 0.8.3dev - 2014-07-02
 */

class PdfAdhesionFormModel extends PdfModel
{
    /**
     * Main constructor
     *
     * @param Db          $zdb         Database instance
     * @param Preferences $preferences Galette preferences
     * @param mixed       $args        Arguments
     */
    public function __construct(Db $zdb, Preferences $preferences, $args = null)
    {
        parent::__construct($zdb, $preferences, self::ADHESION_FORM_MODEL, $args);
        $this->setPatterns($this->getMemberPatterns());
    }
}
